Learn R Programming

genpb (version 0.0.14)

findHetBind: find sites of heterozygous binding in ChIP-seq experiments

Description

find sites of heterozygous binding in ChIP-seq experiments

Usage

findHetBind(v, qm, locs, m = 4, seqn = "chr17")

Arguments

v
pileup array, seq element of applyPileups
qm
quality matrix, qual element of applyPileups
locs
numeric vector of genomic coordinates of locations in v
m
minimum number of calls for two distinct nucleotides required to declare heterozygous binding
seqn
chromosome name

Value

  • a GRanges instance with base-specific metadata and quality summaries in elementMetadata

Details

used in getPupChunk

Examples

Run this code
# not yet

Run the code above in your browser using DataLab